==> mp3-combine-and-split-0.0.6.tar.gz: mp3-combine-and-split-0.0.6/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["Click>=7.0", "pydub", "eyed3", "natsort"]

setup_requirements = [
    "pytest-runner",
]

test_requirements = [
    "pytest>=3",
]

setup(
    author="Philip Roche",
    author_email="phil@philroche.net",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Utility to Combine MP3 and then split based on a defined max play time. ",
    entry_points={
        "console_scripts": [
            "mp3-combine-and-split=mp3_combine_and_split.cli:main",
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="mp3_combine_and_split",
    name="mp3-combine-and-split",
    packages=find_packages(
        include=["mp3_combine_and_split", "mp3_combine_and_split.*"]
    ),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/philroche/mp3_combine_and_split",
    version="0.0.6",
    zip_safe=False,
)

==> mp3-combine-and-split-0.0.7.tar.gz: mp3-combine-and-split-0.0.7/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["Click>=7.0", "pydub", "eyed3", "natsort", "python-slugify"]

setup_requirements = [
    "pytest-runner",
]

test_requirements = [
    "pytest>=3",
]

setup(
    author="Philip Roche",
    author_email="phil@philroche.net",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Utility to Combine MP3 and then split based on a defined max play time. ",
    entry_points={
        "console_scripts": [
            "mp3-combine-and-split=mp3_combine_and_split.cli:main",
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="mp3_combine_and_split",
    name="mp3-combine-and-split",
    packages=find_packages(
        include=["mp3_combine_and_split", "mp3_combine_and_split.*"]
    ),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/philroche/mp3_combine_and_split",
    version="0.0.7",
    zip_safe=False,
)
